@@ -73,8 +73,8 @@ class KeyphraseTfidfVectorizer(KeyphraseCountVectorizer):
         The `regex pattern`_ of `POS-tags`_ used to extract a sequence of POS-tagged tokens from the text.
         Standard is to only select keyphrases that have 0 or more adjectives, followed by 1 or more nouns.
 
-    stop_words : str, default='english'
-            Language of stopwords to remove from the document, e.g.'english.
+    stop_words : str, default=None
+            Language of stopwords to remove from the document, e.g. 'english'.
             Supported options are `stopwords available in NLTK`_.
             Removes unwanted stopwords from keyphrases if 'stop_words' is not None.
 
@@ -122,7 +122,7 @@ class KeyphraseTfidfVectorizer(KeyphraseCountVectorizer):
     """
 
     def __init__(self, spacy_pipeline: str = 'en_core_web_sm', pos_pattern: str = '<J.*>*<N.*>+',
-                 stop_words: str = 'english',
+                 stop_words: str = None,
                  lowercase: bool = True, workers: int = 1, max_df: int = None, min_df: int = None,
                  binary: bool = False,
                  dtype: np.dtype = np.float64, norm: str = "l2",
@@ -135,9 +135,10 @@ class KeyphraseTfidfVectorizer(KeyphraseCountVectorizer):
                 "'workers' parameter must be of type int"
             )
 
-        if (workers < -1) or (workers > psutil.cpu_count(logical=True)):
+        if (workers < -1) or (workers > psutil.cpu_count(logical=True)) or (workers == 0):
             raise ValueError(
-                "'workers' parameter value must be between -1 and " + str(psutil.cpu_count(logical=True))
+                "'workers' parameter value cannot be 0 and must be between -1 and " + str(
+                    psutil.cpu_count(logical=True))
             )
 
         self.spacy_pipeline = spacy_pipeline
