@@ -9,12 +9,11 @@ import logging
 import os
 from typing import List
 
+import nltk
 import numpy as np
 import psutil
 import scipy.sparse as sp
 import spacy
-from nltk import RegexpParser
-from nltk.corpus import stopwords
 
 
 class _KeyphraseVectorizerMixin():
@@ -190,7 +189,7 @@ class _KeyphraseVectorizerMixin():
             List of text documents from which to extract the keyphrases.
 
         stop_words : str
-            Language of stopwords to remove from the document, e.g.'english.
+            Language of stopwords to remove from the document, e.g. 'english'.
             Supported options are `stopwords available in NLTK`_.
             Removes unwanted stopwords from keyphrases if 'stop_words' is not None.
 
@@ -229,9 +228,9 @@ class _KeyphraseVectorizerMixin():
             )
 
         # triggers a parameter validation
-        if not isinstance(stop_words, str):
+        if not isinstance(stop_words, str) and (stop_words is not None):
             raise ValueError(
-                "'stop_words' parameter needs to be a string. E.g. 'english'"
+                "'stop_words' parameter needs to be a string, e.g. 'english' or 'None'"
             )
 
         # triggers a parameter validation
@@ -252,18 +251,33 @@ class _KeyphraseVectorizerMixin():
                 "'workers' parameter must be of type int"
             )
 
-        if (workers < -1) or (workers > psutil.cpu_count(logical=True)):
+        if (workers < -1) or (workers > psutil.cpu_count(logical=True)) or (workers == 0):
             raise ValueError(
-                "'workers' parameter value must be between -1 and " + str(psutil.cpu_count(logical=True))
+                "'workers' parameter value cannot be 0 and must be between -1 and " + str(
+                    psutil.cpu_count(logical=True))
             )
 
         stop_words_list = []
         if stop_words:
-            stop_words_list = set(stopwords.words(stop_words))
+            try:
+                stop_words_list = set(nltk.corpus.stopwords.words(stop_words))
+            except LookupError:
+                logger = logging.getLogger('KeyphraseVectorizer')
+                logger.setLevel(logging.WARNING)
+                sh = logging.StreamHandler()
+                sh.setFormatter(logging.Formatter(
+                    '%(asctime)s - %(name)s - %(levelname)s - %(message)s'))
+                logger.addHandler(sh)
+                logger.setLevel(logging.DEBUG)
+                logger.info(
+                    'It looks like you do not have downloaded a list of stopwords yet. It is attempted to download the stopwords now.')
+                nltk.download('stopwords')
+                stop_words_list = set(nltk.corpus.stopwords.words(stop_words))
 
         # add spaCy POS tags for documents
-        spacy_exclude = ['parser', 'ner', 'entity_linker', 'entity_ruler', 'textcat', 'textcat_multilabel',
-                         'lemmatizer', 'morphologizer', 'senter', 'sentencizer', 'transformer']
+
+        # ToDo: add parameter to be able to exclude custom pipeline components for faster processing
+        spacy_exclude = []
         try:
             nlp = spacy.load(spacy_pipeline,
                              exclude=spacy_exclude)
@@ -283,9 +297,6 @@ class _KeyphraseVectorizerMixin():
             nlp = spacy.load(spacy_pipeline,
                              exclude=spacy_exclude)
 
-        # add rule based sentence boundary detection
-        nlp.add_pipe('sentencizer')
-
         keyphrases_list = []
         if workers != 1:
             os.environ["TOKENIZERS_PARALLELISM"] = "false"
@@ -296,17 +307,17 @@ class _KeyphraseVectorizerMixin():
         max_doc_length = 1000000
         for document in document_list:
             if len(document) > max_doc_length:
-                docs_list.append(self._split_long_document(text=document, max_text_length=max_doc_length))
+                docs_list.extend(self._split_long_document(text=document, max_text_length=max_doc_length))
             else:
-                docs_list.append([document])
-        document_list = [text for split_text in docs_list for text in split_text]
+                docs_list.append(document)
+        document_list = docs_list
         del docs_list
 
         # increase max length of documents that spaCy can parse
         # (should only be done if parser and ner are not used due to memory issues)
         nlp.max_length = max([len(doc) for doc in document_list]) + 100
 
-        cp = RegexpParser('CHUNK: {(' + pos_pattern + ')}')
+        cp = nltk.RegexpParser('CHUNK: {(' + pos_pattern + ')}')
         for tagged_doc in nlp.pipe(document_list, n_process=workers):
             tagged_pos_doc = []
             for sentence in tagged_doc.sents:
